<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" indent="yes"/>
<xsl:template match="firewall">
  <xsl:choose>
    <xsl:when test="@module = 'VeryTight' or @module = 'VeryTight2'">
      <xsl:choose>
        <xsl:when test="@moduleVersion = 2.1">
          <!-- upgrade from 2.1 to 2.2 -->
          <xsl:call-template name="convert-2.1-2.2" />
        </xsl:when>
      </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
      Invalid module specified!  module = <xsl:value-of select="@module" /><xsl:message terminate="yes"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="convert-2.1-2.2">
<firewall module="{@module}" moduleVersion="2.2">
  <xsl:call-template name="convert-2.1-2.2-config" />
  <xsl:call-template name="convert-2.1-2.2-networks" />
  <xsl:call-template name="convert-2.1-2.2-reserved" />
  <xsl:call-template name="convert-2.1-2.2-zones" />
  <xsl:copy-of select="services" />
  <xsl:call-template name="convert-2.1-2.2-paths" />
</firewall>
</xsl:template>

<!-- This is the major template needed for 2.1 to 2.2 conversion -->
<xsl:template name="convert-2.1-2.2-disabled">
  <xsl:param name="disabled" />
  <xsl:choose>
    <xsl:when test="$disabled = 'false'">
      <xsl:attribute name="active">true</xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
      <xsl:attribute name="active">false</xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:attribute-set name="module-2.1">
  <xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
  <xsl:attribute name="params"><xsl:value-of select="@params" /></xsl:attribute>
</xsl:attribute-set>

<xsl:template name="convert-2.1-2.2-config">
  <config>
    <xsl:copy-of select="config/networkCommand" />
    <xsl:copy-of select="config/mangleRules" />
    <xsl:copy-of select="config/ecn" />
    <xsl:copy-of select="config/bridgeSupport" />
    <xsl:copy-of select="config/snortInlineSupport" />
    <xsl:copy-of select="config/dynamicInterfaces" />
    <xsl:copy-of select="config/validityChecks" />
    <moduleSupport kernel="{config/moduleSupport/@kernel}">
      <xsl:for-each select="config/moduleSupport/module">
        <xsl:element name="conntracker" use-attribute-sets="module-2.1">
          <xsl:attribute name="active"><xsl:value-of select="@enabled" /></xsl:attribute>
        </xsl:element>
      </xsl:for-each>
    </moduleSupport>
    <xsl:copy-of select="config/internal" />
    <xsl:copy-of select="config/ipsec" />
    <xsl:copy-of select="config/dmz" />
    <xsl:copy-of select="config/dialin" />
    <xsl:copy-of select="config/log" />
    <xsl:copy-of select="config/logRate" />
    <xsl:copy-of select="config/limitRate" />
  </config>
</xsl:template>

<!-- define those attributes that need to come over from a 2.1 to 2.2 config file -->
<xsl:attribute-set name="networks-2.1">
  <xsl:attribute name="value"><xsl:value-of select="@value" /></xsl:attribute>
  <xsl:attribute name="type"><xsl:value-of select="@type" /></xsl:attribute>
  <xsl:attribute name="index"><xsl:value-of select="@index" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:template name="convert-2.1-2.2-networks">
  <networks>
    <xsl:for-each select="networks/addr">
      <xsl:element name="addr" use-attribute-sets="networks-2.1">
        <xsl:call-template name="convert-2.1-2.2-disabled" >
          <xsl:with-param name="disabled" select="@disabled" />
        </xsl:call-template>
      </xsl:element>
    </xsl:for-each>
  </networks>
</xsl:template>

<!-- define those attributes that need to come over from a 2.1 to 2.2 config file -->
<xsl:attribute-set name="reserved-2.1">
  <xsl:attribute name="value"><xsl:value-of select="@value" /></xsl:attribute>
  <xsl:attribute name="limitTo"><xsl:value-of select="@limitTo" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:template name="convert-2.1-2.2-reserved">
  <reserved>
    <xsl:for-each select="reserved/addr">
      <xsl:element name="addr" use-attribute-sets="reserved-2.1">
        <xsl:call-template name="convert-2.1-2.2-disabled" >
          <xsl:with-param name="disabled" select="@disabled" />
        </xsl:call-template>
      </xsl:element>
    </xsl:for-each>
  </reserved>
</xsl:template>

<!-- define those attributes that need to come over from a 2.1 to 2.2 config file -->
<xsl:attribute-set name="zone-non-ipsec-2.1">
  <xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
  <xsl:attribute name="alias"><xsl:value-of select="@alias" /></xsl:attribute>
  <xsl:attribute name="ip"><xsl:value-of select="@ip" /></xsl:attribute>
  <xsl:attribute name="ipsec"><xsl:value-of select="@ipsec" /></xsl:attribute>
  <xsl:attribute name="ipsecLimitFrom"><xsl:value-of select="@ipsecLimitFrom" /></xsl:attribute>
  <xsl:attribute name="network"><xsl:value-of select="@network" /></xsl:attribute>
  <xsl:attribute name="proxyarp"><xsl:value-of select="@proxyarp" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="zone-ipsec-2.1">
  <xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
  <xsl:attribute name="alias"><xsl:value-of select="@alias" /></xsl:attribute>
  <xsl:attribute name="boundTo"><xsl:value-of select="@boundTo" /></xsl:attribute>
  <xsl:attribute name="network"><xsl:value-of select="@network" /></xsl:attribute>
  <xsl:attribute name="proxyarp"><xsl:value-of select="@proxyarp" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:template name="convert-2.1-2.2-zones">
  <zones>
    <xsl:for-each select="zones/zone">
      <zone type="{@type}">
      <xsl:variable name="zoneType" select="@type" />
      <xsl:for-each select="interface">
        <xsl:choose>
          <xsl:when test="$zoneType = 'ipsec'">
            <xsl:element name="interface" use-attribute-sets="zone-ipsec-2.1">
              <xsl:call-template name="convert-2.1-2.2-disabled" >
                <xsl:with-param name="disabled" select="@disabled" />
              </xsl:call-template>
            </xsl:element>
          </xsl:when>
          <xsl:otherwise>
            <xsl:element name="interface" use-attribute-sets="zone-non-ipsec-2.1">
              <xsl:call-template name="convert-2.1-2.2-disabled" >
                <xsl:with-param name="disabled" select="@disabled" />
              </xsl:call-template>
            </xsl:element>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>
      </zone>
    </xsl:for-each>
  </zones>
</xsl:template>

<!-- define those attributes that need to come over from a 2.1 to 2.2 config file -->
<xsl:attribute-set name="serviceGroup-2.1">
  <xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="path-incoming-2.1">
  <xsl:attribute name="type"><xsl:value-of select="@type" /></xsl:attribute>
  <xsl:attribute name="i"><xsl:value-of select="@i" /></xsl:attribute>
  <xsl:attribute name="limitFrom"><xsl:value-of select="@limitFrom" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="path-outgoing-2.1">
  <xsl:attribute name="type"><xsl:value-of select="@type" /></xsl:attribute>
  <xsl:attribute name="o"><xsl:value-of select="@o" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="path-both-2.1">
  <xsl:attribute name="type"><xsl:value-of select="@type" /></xsl:attribute>
  <xsl:attribute name="i"><xsl:value-of select="@i" /></xsl:attribute>
  <xsl:attribute name="limitFrom"><xsl:value-of select="@limitFrom" /></xsl:attribute>
  <xsl:attribute name="o"><xsl:value-of select="@o" /></xsl:attribute>
  <xsl:attribute name="limitTo"><xsl:value-of select="@limitTo" /></xsl:attribute>
  <xsl:attribute name="comment"><xsl:value-of select="@comment" /></xsl:attribute>
</xsl:attribute-set>

<xsl:template name="convert-2.1-2.2-paths">
  <paths>
    <xsl:for-each select="paths/serviceGroup">
      <xsl:element name="serviceGroup" use-attribute-sets="serviceGroup-2.1">
        <xsl:call-template name="convert-2.1-2.2-disabled" >
          <xsl:with-param name="disabled" select="@disabled" />
        </xsl:call-template>
        <xsl:for-each select="path">
          <xsl:variable name="pathType" select="@type" />
          <xsl:choose>
            <xsl:when test="$pathType = 'internalBroadcast' or $pathType = 'externalBroadcast' or $pathType = 'ipsecBroadcast' or $pathType = 'dmzBroadcast' or $pathType = 'dialinBroadcast' or $pathType = 'internalToFirewall' or $pathType = 'externalToFirewall' or $pathType = 'ipsecToFirewall' or $pathType = 'dmzToFirewall' or $pathType = 'dialinToFirewall'">
              <xsl:element name="path" use-attribute-sets="path-incoming-2.1">
                <xsl:call-template name="convert-2.1-2.2-disabled" >
                  <xsl:with-param name="disabled" select="@disabled" />
                </xsl:call-template>
                <!-- handle the ip attribute -->
                <xsl:if test="($pathType = 'internalToFirewall' or $pathType = 'externalToFirewall' or $pathType = 'ipsecToFirewall' or $pathType = 'dmzToFirewall' or $pathType = 'dialinToFirewall') and @ip != ''"><xsl:attribute name="ip"><xsl:value-of select="@ip" /></xsl:attribute></xsl:if>
                <xsl:copy-of select="./*" />
              </xsl:element>
            </xsl:when>
            <xsl:when test="$pathType = 'firewallToInternal' or $pathType = 'firewallToExternal' or $pathType = 'firewallToIPSec' or $pathType = 'firewallToDMZ' or $pathType = 'firewallToDialin' or $pathType = 'firewallToFirewall'">
              <xsl:element name="path" use-attribute-sets="path-outgoing-2.1">
                <xsl:call-template name="convert-2.1-2.2-disabled" >
                  <xsl:with-param name="disabled" select="@disabled" />
                </xsl:call-template>
                <xsl:if test="$pathType != 'firewallToFirewall'">
                  <xsl:attribute name="limitTo"><xsl:value-of select="@limitTo" /></xsl:attribute>
                </xsl:if>
                <xsl:copy-of select="./*" />
              </xsl:element>
            </xsl:when>
            <xsl:otherwise>
              <xsl:element name="path" use-attribute-sets="path-both-2.1">
                <xsl:call-template name="convert-2.1-2.2-disabled" >
                  <xsl:with-param name="disabled" select="@disabled" />
                </xsl:call-template>
                <xsl:copy-of select="./*" />
              </xsl:element>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>
      </xsl:element>
    </xsl:for-each>
  </paths>
</xsl:template>

</xsl:stylesheet>